LocalChange

Struct LocalChange 

pub struct LocalChange<Hunk, Author> {
    pub offsets: Offsets,
    pub hashed: Hashed<Hunk, Author>,
    pub unhashed: Option<Value>,
    pub contents: Vec<u8>,
}

Fields

offsets: Offsetshashed: Hashed<Hunk, Author>unhashed: Option<Value>

unhashed TOML extra contents.

contents: Vec<u8>

The contents.

Implementations

Source

impl LocalChange<Hunk<Option<Hash>, Local>, Author>

pub fn write_all_deps_old<F: FnMut(Hash) -> Result<(), ChangeError>>( &self, f: F, ) -> Result<(), ChangeError>

pub fn write<W: WriteChangeLine, C: ChangeStore>( &self, changes: &C, hash: Option<Hash>, write_header: bool, w: W, ) -> Result<(), TextSerError<C::Error>>

Source

impl LocalChange<BaseHunk<Atom<Option<Hash>>, Local>, Author>

pub fn read_and_deps<R: BufRead, T: ChannelTxnT + DepsTxnT<DepsError = <T as GraphTxnT>::GraphError>>( r: R, updatables: &mut HashMap<usize, InodeUpdate>, txn: &T, channel: &ChannelRef<T>, ) -> Result<Self, TextDeErrorDeps<T>>

pub fn read<R: BufRead>( r: R, updatables: &mut HashMap<usize, InodeUpdate>, ) -> Result<Self, TextDeError>

Source

impl LocalChange<BaseHunk<Atom<Option<Hash>>, Local>, Author>

pub fn knows(&self, hash: &Hash) -> bool

pub fn has_edge( &self, hash: Hash, from: Position<Option<Hash>>, to: Position<Option<Hash>>, flags: EdgeFlags, ) -> bool

Source

impl LocalChange<BaseHunk<Atom<Option<Hash>>, Local>, Author>

pub fn inverse( &self, hash: &Hash, header: ChangeHeader, metadata: Vec<u8>, ) -> Self

Source

impl LocalChange<Hunk<Option<Hash>, Local>, Author>

pub const OFFSETS_SIZE: u64 = 56

pub fn make_change<T: ChannelTxnT + DepsTxnT<DepsError = <T as GraphTxnT>::GraphError>>( txn: &T, channel: &ChannelRef<T>, changes: Vec<Hunk<Option<Hash>, Local>>, contents: Vec<u8>, header: ChangeHeader, metadata: Vec<u8>, ) -> Result<Self, MakeChangeError<T>>

pub fn write_all_deps<F: FnMut(Hash) -> Result<(), ChangeError>>( &self, f: F, ) -> Result<(), ChangeError>

Source

impl LocalChange<BaseHunk<Atom<Option<Hash>>, Local>, Author>

pub fn size_no_contents<R: Read + Seek>(r: &mut R) -> Result<u64, ChangeError>

pub fn serialize<W: Write, E: From<ChangeError>, F: FnOnce(&mut Self, &Hash) -> Result<(), E>>( &mut self, w: W, f: F, ) -> Result<Hash, E>

Serialise the change as a file named “.change” in directory dir, where “” is the actual hash of the change.

pub fn check_from_buffer(buf: &[u8], hash: &Hash) -> Result<(), ChangeError>

Deserialise a change from the file given as input file.

pub fn deserialize(file: &str, hash: Option<&Hash>) -> Result<Self, ChangeError>

Deserialise a change from the file given as input file.

pub fn hash(&self) -> Result<Hash, Error>

Compute the hash of this change. If the zstd feature is enabled, it is probably more efficient to serialise the change (using the serialize method) at the same time, which also returns the hash.

Methods from Deref<Target = Hashed<Hunk<Option<Hash>, Local>, Author>>

pub fn write_all_deps<F: FnMut(Hash) -> Result<(), ChangeError>>( &self, f: F, ) -> Result<(), ChangeError>