pub struct SerializedChannel { /* private fields */ }Trait Implementations
Sourceimpl Check for SerializedChannel
impl Check for SerializedChannel
Sourceimpl Clone for SerializedChannel
impl Clone for SerializedChannel
Sourcefn clone(&self) -> SerializedChannel
fn clone(&self) -> SerializedChannel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SerializedChannel
Sourceimpl Debug for SerializedChannel
impl Debug for SerializedChannel
impl Eq for SerializedChannel
Sourceimpl Ord for SerializedChannel
impl Ord for SerializedChannel
Sourcefn cmp(&self, other: &SerializedChannel) -> Ordering
fn cmp(&self, other: &SerializedChannel) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SerializedChannel
impl PartialEq for SerializedChannel
Sourceimpl PartialOrd for SerializedChannel
impl PartialOrd for SerializedChannel
Sourceimpl Storable for SerializedChannel
impl Storable for SerializedChannel
Sourcetype PageReferences = Empty<u64>
type PageReferences = Empty<u64>
An iterator over the offsets to pages contained in this
value. Only values from this crate can generate non-empty
iterators, but combined values (like tuples) must chain the
iterators returned by method
page_offsets.Sourcefn page_references(&self) -> Self::PageReferences
fn page_references(&self) -> Self::PageReferences
If this value is an offset to another page at offset
offset,
return Some(offset). Return None else.impl StructuralPartialEq for SerializedChannel
Sourceimpl UnsizedStorable for SerializedChannel
impl UnsizedStorable for SerializedChannel
Sourcefn size(&self) -> usize
fn size(&self) -> usize
If Self::SIZE.is_some(), this must return the same
value. The default implementation is Self;:SIZE.unwrap().
const ALIGN: usize
Sourceunsafe fn write_to_page(&self, p: *mut u8)
unsafe fn write_to_page(&self, p: *mut u8)
Write to a page. Must not overwrite the allocated size, but
this isn’t checked (which is why it’s unsafe).
unsafe fn from_raw_ptr<'a, T>(_: &T, p: *const u8) -> &'a Self