pub struct SerializedPublicKey { /* private fields */ }Trait Implementations
Sourceimpl Debug for SerializedPublicKey
impl Debug for SerializedPublicKey
impl Eq for SerializedPublicKey
Sourceimpl Ord for SerializedPublicKey
impl Ord for SerializedPublicKey
Sourcefn cmp(&self, other: &SerializedPublicKey) -> Ordering
fn cmp(&self, other: &SerializedPublicKey) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SerializedPublicKey
impl PartialEq for SerializedPublicKey
Sourceimpl PartialOrd for SerializedPublicKey
impl PartialOrd for SerializedPublicKey
Sourceimpl Storable for SerializedPublicKey
impl Storable for SerializedPublicKey
Sourcetype PageReferences = Empty<u64>
type PageReferences = Empty<u64>
An iterator over the offsets to pages contained in this
value. Only values from this crate can generate non-empty
iterators, but combined values (like tuples) must chain the
iterators returned by method
page_offsets.Sourcefn page_references(&self) -> Self::PageReferences
fn page_references(&self) -> Self::PageReferences
If this value is an offset to another page at offset
offset,
return Some(offset). Return None else.impl StructuralPartialEq for SerializedPublicKey
Sourceimpl UnsizedStorable for SerializedPublicKey
impl UnsizedStorable for SerializedPublicKey
Sourcefn size(&self) -> usize
fn size(&self) -> usize
If Self::SIZE.is_some(), this must return the same
value. The default implementation is Self;:SIZE.unwrap().
const ALIGN: usize
Sourceunsafe fn write_to_page(&self, p: *mut u8)
unsafe fn write_to_page(&self, p: *mut u8)
Write to a page. Must not overwrite the allocated size, but
this isn’t checked (which is why it’s unsafe).
unsafe fn from_raw_ptr<'a, T>(_: &T, p: *const u8) -> &'a Self