pub struct SerializedRemote { /* private fields */ }Trait Implementations
Sourceimpl Check for SerializedRemote
impl Check for SerializedRemote
Sourceimpl Debug for SerializedRemote
impl Debug for SerializedRemote
impl Eq for SerializedRemote
Sourceimpl Ord for SerializedRemote
impl Ord for SerializedRemote
Sourceimpl PartialEq for SerializedRemote
impl PartialEq for SerializedRemote
Sourceimpl PartialOrd for SerializedRemote
impl PartialOrd for SerializedRemote
Sourceimpl Storable for SerializedRemote
impl Storable for SerializedRemote
Sourcetype PageReferences = Empty<u64>
type PageReferences = Empty<u64>
An iterator over the offsets to pages contained in this
value. Only values from this crate can generate non-empty
iterators, but combined values (like tuples) must chain the
iterators returned by method
page_offsets.Sourcefn page_references(&self) -> Self::PageReferences
fn page_references(&self) -> Self::PageReferences
If this value is an offset to another page at offset
offset,
return Some(offset). Return None else.impl StructuralPartialEq for SerializedRemote
Sourceimpl UnsizedStorable for SerializedRemote
impl UnsizedStorable for SerializedRemote
const ALIGN: usize = 8
Sourcefn size(&self) -> usize
fn size(&self) -> usize
If
Self::SIZE.is_some(), this must return the same
value. The default implementation is Self;:SIZE.unwrap().Sourceunsafe fn onpage_size(p: *const u8) -> usize
unsafe fn onpage_size(p: *const u8) -> usize
Read the size from an on-page entry. If
Self::SIZE.is_some()
this must be the same value.unsafe fn from_raw_ptr<'a, T>(_: &T, p: *const u8) -> &'a Self
Sourceunsafe fn write_to_page_alloc<T: AllocPage>(&self, _: &mut T, p: *mut u8)
unsafe fn write_to_page_alloc<T: AllocPage>(&self, _: &mut T, p: *mut u8)
Write to a page. Must not overwrite the allocated size, but
this isn’t checked (which is why it’s unsafe). Read more
Sourceunsafe fn write_to_page(&self, _: *mut u8)
unsafe fn write_to_page(&self, _: *mut u8)
Write to a page. Must not overwrite the allocated size, but
this isn’t checked (which is why it’s unsafe).