pub enum InodeUpdate {
Add {
pos: ChangePosition,
inode: Inode,
},
Deleted {
inode: Inode,
},
}Expand description
An account of the files that have been added, moved or deleted, as returned by record, and used by apply (when applying a change created locally) to update the trees and inodes databases.
Variants