pub struct Recorded {
pub contents: Arc<Mutex<Vec<u8>>>,
pub actions: Vec<Hunk<Option<ChangeId>, LocalByte>>,
pub updatables: HashMap<usize, InodeUpdate>,
pub largest_file: u64,
pub has_binary_files: bool,
pub oldest_change: SystemTime,
pub redundant: Vec<Redundant>,
/* private fields */
}Expand description
The result of recording a change:
Fields
contents: Arc<Mutex<Vec<u8>>>The “byte contents” of the change.
actions: Vec<Hunk<Option<ChangeId>, LocalByte>>The current records, to be lated converted into change operations.
updatables: HashMap<usize, InodeUpdate>The updates that need to be made to the tree and revtree
tables when this change is applied to the local repository.
largest_file: u64The size of the largest file that was recorded in this change.
has_binary_files: boolWhether we have recorded binary files.
oldest_change: SystemTimeTimestamp of the oldest changed file. If nothing changed, returns now().
redundant: Vec<Redundant>Redundant edges found during the comparison.
Implementations
Sourceimpl Recorded
impl Recorded
pub fn take_updatables(&mut self) -> HashMap<usize, InodeUpdate>
pub fn into_change<T: ChannelTxnT + DepsTxnT<DepsError = <T as GraphTxnT>::GraphError>>( self, txn: &T, channel: &ChannelRef<T>, header: ChangeHeader, ) -> Result<LocalChangeLocal, MakeChangeError<T>>